import numpy as np

#   Plots elements names
XS = "xs"
YS = "ys"
VOLUME_NAMES = "volume_names"
COMPO_NAMES = "compo_names"
COLORS = "colors"
EDGE_COLORS = "edge_colors"
POLYGONS = "polygons"
GRID = "grid"

#   Default field names
MESH = "Mesh"
MATERIAL = "Material"

#   Default file names
GEOMETRY = "Geometry"
CSV = "CSV"

# Axis coordinates
X = (1., 0., 0.)
Y = (0., 1., 0.)
Z = (0., 0., 1.)

# Cell name to define the outside world
OUTSIDE = np.inf
